@@ -56,10 +56,6 @@ if not os.path.exists(args.initfile):
 else:
   initfile = args.initfile
 
-if not os.path.exists(initfile):
-  print("Error! Initfile", initfile, "does not exist. Exiting...", file=sys.stderr)
-  sys.exit(1)
-
 if args.verbose:
   debug = 1
 else:
@@ -323,7 +319,10 @@ for s in sysinit:
       print("Removing", glob.glob(spath)[0])
     if dryrun == 0:
       os.remove(glob.glob(spath)[0])
-increment = 100 // len(sysinit)
+if len(sysinit) > 0:
+  increment = 100 // len(sysinit)
+else:
+  increment = 99
 sid = 0
 for s in sysinit:
   sname = s[hindex["name"]]
